const system = require("../../../system");
const ServiceBase = require("../../sve.base");
const settings = require("../../../../config/settings");

class ProductTypeService extends ServiceBase {
  constructor() {
    super("dbproduct", ServiceBase.getDaoName(ProductTypeService));
  }

  async getProductTypeInfo(actionBody, appInfo) {
    if (!actionBody.type) {
      return system.getResult(null, "channelCode item is data empty ！");
    }
    if (!appInfo) {
      return system.getResult(null, "appInfo item is data empty ！");
    }
    var producttypeinfo = await this.findOne({ "channel_type_code": actionBody.type, "uapp_id": appInfo.uapp_id });
    return system.getResultSuccess(producttypeinfo);
  }

  /**
 * 获取全部产品大类
 * @returns {Promise<void>}
 */
  async getAllProductType(actionBody) {
    var tmpWhere = {
      pageInfo: {}
    };
    if (actionBody) {
      if (actionBody.pageSize) {
        tmpWhere.limit = actionBody.pageSize;
      }
      if (actionBody.current) {
        let current = actionBody.current;
        tmpWhere.offset = (current - 1) * actionBody.pageSize;
      }
    }
    let result = await this.dao.model.findAndCountAll(tmpWhere)
    return system.getResultSuccess(result);
  }

  /**
   * 创建产品大类
   * @returns {Promise<void>}
   */
  async submitProductType(actionBody) {
    let result = await this.dao.model.create(actionBody)
    return system.getResultSuccess(result);
  }

  /**
   * 修改产品大类
   * @returns {Promise<void>}
   */
  async editProductType(actionBody) {
    if (actionBody) {
      let result = await this.dao.update(actionBody)
      return system.getResultSuccess(result);
    }
    return;
  }
}
module.exports = ProductTypeService;
